==> react-bootstrap-design-0.3.0.tgz: package/src/configurations/models/ColorfulChrono.js <==
var AllStyles = require('../AllStyles');

var ColorfulChrono = {
    burst : true,
    case : {
        shape : AllStyles.shape.roundedCircle,
        bg : AllStyles.background.steel,
    },
    dial : {
        shape : AllStyles.shape.roundedCircle,
        bg : AllStyles.background.faded
    },
    hands : {
        type : {
            hour : 'hour',
            minute : 'minute',
            second : 'second'
        },
        hour : {
            color : AllStyles.background.primary
        },
        minute : {
            color : AllStyles.background.inverse
        }
    },
    header : 'Toronto',
    index : {
        color : AllStyles.background.inverse,
        nodeCount : AllStyles.index.type.hour,
        customNode : {
            3 : {
                display : AllStyles.display.none
            },
            6 : {
                display : AllStyles.display.none
            },            
            9 : {
                display : AllStyles.display.none
            },
            12 : {
                display : AllStyles.display.none
            }
        }
    },
    grid : {
        2 : {
            label : {
                color : AllStyles.color.gray,
                font : AllStyles.font.monoton,
                text : 'RBD'
            }
        },
        4 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.success
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse
            }     
        },
        6 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.info
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse
            }
        },
        8 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.warning
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse,
                type : 'second'
            }
        }        
    },
    timeZone : -4    
}

module.exports = ColorfulChrono;

==> react-bootstrap-design-0.6.0.tgz: package/src/configurations/models/ColorfulChrono.js <==
var AllStyles = require('../AllStyles');

var ColorfulChrono = {
    burst : true,
    case : {
        shape : AllStyles.shape.roundedCircle,
        bg : AllStyles.background.steel,
    },
    dial : {
        shape : AllStyles.shape.roundedCircle,
        bg : AllStyles.background.faded
    },
    hands : {
        type : {
            hour : 'hour',
            minute : 'minute',
            second : 'second'
        },
        hour : {
            color : AllStyles.background.primary,
            length : '30%',
            margin : '0 20%',
            width : '4px'
        },
        minute : {
            color : AllStyles.background.inverse
        }
    },
    header : 'Toronto',
    index : {
        color : AllStyles.background.inverse,
        nodeCount : AllStyles.index.type.hour,
        customNode : {
            3 : {
                display : AllStyles.display.none
            },
            6 : {
                display : AllStyles.display.none
            },            
            9 : {
                display : AllStyles.display.none
            },
            12 : {
                display : AllStyles.display.none
            }
        }
    },
    grid : {
        2 : {
            label : {
                color : AllStyles.color.gray,
                font : AllStyles.font.monoton,
                text : 'RBD'
            }
        },
        4 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.success
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse
            }     
        },
        6 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.info
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse
            }
        },
        8 : {
            dial : {
                border : 'solid black 1px',
                shape : AllStyles.shape.roundedCircle,
                bg : AllStyles.background.warning
            },
            index : {
                color : AllStyles.background.inverse,
                nodeCount : AllStyles.index.type.hour
            },
            hand : {
                color : AllStyles.background.inverse,
                type : 'second'
            }
        }        
    },
    timeZone : -4    
}

module.exports = ColorfulChrono;
